//  COPYRIGHT:       PrimeObjects Software Inc. (C) 2022 All Right Reserved
//  COMPANY URL:     https://www.primeobjects.com/
//  CONTACT:         developer@primeobjects.com
//
//  This source is subject to the PrimeObjects License Agreements.
import React from "react";
import { isArray, map } from "lodash";
import { GradientDiv, ResizeDetectorDiv, SVG } from "primeobjects-ui-web-basic";
import { getEntity } from "primeobjects-helper-util";
import { useSolution } from "primeobjects-helper-ui/build/cjs";
export var ListFiltersSection = function (props) {
    var _a, _b;
    var wrapperClassName = (_a = props.wrapperClassName) !== null && _a !== void 0 ? _a : "";
    var wrapperStyle = (_b = props.wrapperStyle) !== null && _b !== void 0 ? _b : {};
    var filters = isArray(props.filters) ? props.filters : [];
    var solution = useSolution();
    var onResize = function (width, height) {
        if (props.onResize)
            props.onResize(width, height);
    };
    var onRemove = function (filter) {
        if (props.onRemove)
            props.onRemove(filter);
    };
    var renderFilters = function () {
        return map(filters, function (filter, index) {
            var _a;
            var icon = "/icons/platform/".concat(filter.type, ".svg");
            if (filter.entityName) {
                icon = (_a = getEntity(solution, filter.entityName)) === null || _a === void 0 ? void 0 : _a.icon;
            }
            return (React.createElement("div", { key: index, className: "float-left flex px-2 py-1 mb-2 mr-1 shadow-sm border border-gray-100 rounded-md bg-white items-center h-8" },
                React.createElement(SVG, { src: icon, style: { width: 15 } }),
                React.createElement(GradientDiv, { className: "text-sm mx-2 leading-none h-5 items-center", tooltip: filter.text, style: { maxWidth: filter.type == "search" ? 80 : 200 } }, filter.text),
                React.createElement(SVG, { src: "/icons/platform/x.svg", size: 12, className: "cursor-pointer", onClick: function () { return onRemove(filter); } })));
        });
    };
    return (React.createElement(React.Fragment, null, filters.length > 0 && (React.createElement(ResizeDetectorDiv, { className: "float-left w-full px-4 pt-4 pb-2 ".concat(wrapperClassName), style: wrapperStyle, onDetect: onResize }, renderFilters()))));
};
export default ListFiltersSection;
//# sourceMappingURL=filters.js.map